######################
Tutorials and Examples
######################

Here is a collection of different tutorials to help you learn GAMer.

.. _PyGAMer Tutorials:

**********************************
PyGAMer Jupyter Notebook Tutorials
**********************************

.. toctree::
   :maxdepth: 2

   tutorials/notebooks/meshingprotein.ipynb
   tutorials/notebooks/diffusion.ipynb

.. _BlendGAMer Tutorials:

********************
BlendGAMer Tutorials
********************

.. toctree::
   :maxdepth: 2

   tutorials/tutorials/blendertutorial
   tutorials/notebooks/cru_diffusion.ipynb